==> haskell-path-0.9.5-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.5
visibility:           public
id:                   path-0.9.5-Fe7GJgad0iMHiVJ0YaeB5L
key:                  path-0.9.5-Fe7GJgad0iMHiVJ0YaeB5L
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  94c4e1ab8f66f396853d04e3465b6a27
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.5-Fe7GJgad0iMHiVJ0YaeB5L
depends:
    aeson-2.1.2.1-DAjCoZEGWBTDXHPn96Kb1j base-4.17.2.1 deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2
    hashable-1.4.6.0-JiQr1Tltq7G4W5bcwnoSMj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-0.9.5-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path
version:              0.9.5
visibility:           public
id:                   path-0.9.5-1QTUXrM75K81YHb6udJbAa
key:                  path-0.9.5-1QTUXrM75K81YHb6udJbAa
license:              BSD-3-Clause
copyright:            2015–2018 FP Complete
maintainer:           Chris Done <chrisdone@fpcomplete.com>
author:               Chris Done <chrisdone@fpcomplete.com>
synopsis:             Support for well-typed paths
description:          Support for well-typed paths.
category:             System, Filesystem
abi:                  3292bc4670ce57940e38b17ead3f625a
exposed:              True
exposed-modules:
    Path Path.Internal Path.Internal.Posix Path.Internal.Windows
    Path.Posix Path.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-0.9.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path
hs-libraries:         HSpath-0.9.5-1QTUXrM75K81YHb6udJbAa
depends:
    aeson-2.1.2.1-FLNpA1kYfSp7ISjZQSk2AY base-4.17.2.1 deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2
    hashable-1.4.6.0-AVmZwVVVmv9PclG6VBq0Z template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-path/html/path.haddock
haddock-html:         /usr/share/doc/haskell-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
